@@ -1,5 +1,5 @@
 /** -*-c++-*-
- * $Id: siscomponentrecord.cpp,v 1.10 2003/02/05 07:59:08 felfert Exp $
+ * $Id: siscomponentrecord.cpp,v 1.11 2007/07/06 12:08:52 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -27,11 +27,19 @@
 #include <stdio.h>
 #include <string.h>
 
+SISComponentNameRecord::SISComponentNameRecord()
+{
+	m_names = NULL;
+}
+
 SISComponentNameRecord::~SISComponentNameRecord()
 {
-	for (int i = 0; i < m_nameCount; ++i)
-		delete[] m_names[i];
-	delete[] m_names;
+	if (m_names)
+        	{
+		for (int i = 0; i < m_nameCount; ++i)
+			delete[] m_names[i];
+		delete[] m_names;
+		}
 }
 
 SisRC
