@@ -1,4 +1,4 @@
-/* $Id: mp_pfs_ops.c,v 1.11 2001/02/04 04:23:06 felfert Exp $
+/* $Id: mp_pfs_ops.c,v 1.12 2004/09/08 16:46:04 thomasklausner Exp $
  *
  * Original version of this file from p3nfsd-5.4 by
  * Rudolf Koenig (rfkoenig@immd4.informatik.uni-erlangen.de)
@@ -10,7 +10,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <pwd.h>
-#if defined(__SVR4) || defined(__GLIBC__)
+#if defined(__SVR4) || defined(__GLIBC__) || defined(__NetBSD__)
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
