@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsv_api.h,v 1.11 2002/02/14 06:24:33 felfert Exp $
+ * $Id: rfsv_api.h,v 1.12 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -23,6 +23,10 @@
 #ifndef _rfsv_api_h_
 #define _rfsv_api_h_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "mp.h"
 #include "builtins.h"
 
@@ -64,6 +68,10 @@ extern long rpcs_ps();
 #define PSI_A_STREAM		0x0800
 #define PSI_A_TEXT		0x1000
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 /*
